@@ -349,7 +349,7 @@ setReplaceMethod("[",
     }
 })
 
-.compare <- GenomicRanges:::.compare
+.compare <- SummarizedExperiment:::.compare
 ## Appropriate for objects with different ranges and same samples.
 setMethod("rbind", "VCF",
     function(..., deparse.level=1)
@@ -366,8 +366,8 @@ setMethod("rbind", "VCF",
     fixed <- do.call(rbind, lapply(args, fixed))
     info <- do.call(rbind, lapply(args, info))
     rowRanges <- do.call(c, lapply(args, rowRanges))
-    colData <- GenomicRanges:::.cbind.DataFrame(args, colData, "colData")
-    assays <- GenomicRanges:::.bind.arrays(args, rbind, "assays")
+    colData <- SummarizedExperiment:::.cbind.DataFrame(args, colData, "colData")
+    assays <- do.call(rbind, lapply(args, slot, "assays"))
     elementMetadata <- do.call(rbind, lapply(args, slot, "elementMetadata"))
     metadata <- do.call(c, lapply(args, metadata))
 
@@ -400,11 +400,11 @@ setMethod("cbind", "VCF",
         stop("data in 'fixed(VCF)' must match.")
 
     fixed <- fixed(args[[1L]])
-    info <- GenomicRanges:::.cbind.DataFrame(args, info, "info") 
+    info <- SummarizedExperiment:::.cbind.DataFrame(args, info, "info") 
     rowRanges <- rowRanges(args[[1L]])
-    mcols(rowRanges) <- GenomicRanges:::.cbind.DataFrame(args, mcols, "mcols")
+    mcols(rowRanges) <- SummarizedExperiment:::.cbind.DataFrame(args, mcols, "mcols")
     colData <- do.call(rbind, lapply(args, colData))
-    assays <- GenomicRanges:::.bind.arrays(args, cbind, "assays")
+    assays <- do.call(cbind, lapply(args, slot, "assays"))
     metadata <- do.call(c, lapply(args, metadata))
 
     BiocGenerics:::replaceSlots(args[[1L]],
@@ -414,7 +414,55 @@ setMethod("cbind", "VCF",
 })
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### show methods
+### Coercion 
+###
+
+SnpMatrixToVCF <- function(from, seqSource)
+{
+    if (!all(names(from) %in% c("genotypes", "fam", "map")))
+        stop("'from' must be a list with named elements 'genotypes', ",
+             "'fam' and 'map'")
+
+    ## match seqlevels style to seqSource
+    map <- from$map
+    chr <- as.character(map$chromosome)
+    seqlevelsStyle(chr) <- seqlevelsStyle(seqSource)
+    uniqueChr <- unique(chr)
+    if (any(invalid <- !uniqueChr %in% seqlevels(seqSource)))
+        stop("seqlevels not found in 'seqSource': ", 
+             paste(uniqueChr[invalid], collapse=", "))
+
+    ## ref
+    gr <- GRanges(chr, IRanges(map$position, width=1))
+    ref <- getSeq(seqSource, gr)
+
+    ## alt 
+    refIsAlt1 <- ref == map$allele.1
+    refIsAlt2 <- ref == map$allele.2
+    alt <- DNAStringSetList(as.list(map$allele.1))
+    alt[refIsAlt1] <- DNAStringSetList(as.list(map$allele.2[refIsAlt1]))
+    if (any(refNotFound <- refIsAlt1 & refIsAlt2)) {
+        df <- data.frame(rbind(map$allele.1[refNotFound], 
+                               map$allele.2[refNotFound]))
+        alt[refNotFound] <- DNAStringSetList(as.list(df))
+    }
+
+    ## genotypes 
+    GT <- as.raw(from$genotypes)
+    nrowGT <- nrow(from$genotypes)
+    newGT <- c("./.", "0/0", "0/1", "1/1") 
+    GT <- newGT[as.integer(GT) + 1L]
+    GT <- matrix(GT, byrow=TRUE, ncol=nrowGT)
+
+    vcf <- VCF(rowRanges=gr, fixed=DataFrame(REF=ref, ALT=alt), 
+               colData=DataFrame(Samples=seq_len(nrowGT)), 
+               geno=SimpleList(GT=GT))
+    dimnames(vcf) <- list(colnames(from$genotypes), rownames(from$genotypes))
+    vcf
+}
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Show methods
 ###
 
 setMethod(show, "VCF",
@@ -508,18 +556,18 @@ setMethod(show, "VCF",
 }
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### restrictToSNV 
+### restrictToSNV() 
 ###
 
 ### Creates a subset VCF with SNVs only. 'x' can be a CollapsedVCF 
 ### or ExpandedVCF. Data in 'alt(x)' must be DNAStringSet or DNAStringSetList.
 restrictToSNV <- function(x, ...)
 {
-    .Deprecated("isSNV")
+    .Defunct("isSNV")
 }
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### genotypeCodesToNucleotides
+### genotypeCodesToNucleotides()
 ###
 
 genotypeCodesToNucleotides <- function(vcf, ...) 
@@ -530,7 +578,8 @@ genotypeCodesToNucleotides <- function(vcf, ...)
 
     if (is(alt(vcf), "CharacterList"))
         stop("'ALT' must be a DNAStringSetList")
-    ALT <- split(as.character(alt(vcf)@unlistData), togroup(alt(vcf))) 
+    ALT <- as.list(splitAsList(as.character(alt(vcf)@unlistData),
+                   togroup(PartitioningByWidth(alt(vcf))))) 
     REF <- as.character(ref(vcf))
     geno(vcf)$GT <- .geno2geno(NULL, ALT, REF, GT)
     vcf
