@@ -157,8 +157,8 @@ setMethod("relistToClass", "VRanges", function(x) "CompressedVRangesList")
 
 parseFilterStrings <- function(x) {
   x[x == "."] <- NA
-  if (all(is.na(x)))
-    return(matrix(nrow = length(x), ncol = 0L))
+  if (all(x == "PASS", na.rm=TRUE))
+    return(FilterMatrix(matrix(nrow = length(x), ncol = 0L), FilterRules()))
   filterSplit <- strsplit(x, ";", fixed=TRUE)
   filters <- unlist(filterSplit)
   filterNames <- setdiff(unique(filters[!is.na(filters)]), "PASS")
@@ -200,12 +200,19 @@ setAs("VCF", "VRanges", function(from) {
   alt[!nzchar(alt)] <- NA
   alt[alt == "."] <- NA
   ad <- geno(from)$AD
-  if (!is.null(ad) && ncol(from) > 0L) {
-    refDepth <- ad[,,1,drop=FALSE]
-    altDepth <- ad[,,2,drop=FALSE]
-  } else {
-    refDepth <- NA_integer_
-    altDepth <- NA_integer_
+  refDepth <- NA_integer_
+  altDepth <- NA_integer_
+  if (is.array(ad) && ncol(from) > 0L) {
+    if (length(dim(ad)) == 3L) {
+        refDepth <- ad[,,1,drop=FALSE]
+        altDepth <- ad[,,2,drop=FALSE]
+    } else if (length(dim(ad)) == 2L) {
+        RD <- geno(from)$RD
+        if (is.matrix(RD)) {
+            refDepth <- RD
+        }
+        altDepth <- ad
+    }
   }
   totalDepth <- geno(from)$DP
   if (is.null(totalDepth) || ncol(from) == 0L)
@@ -229,7 +236,8 @@ setAs("VCF", "VRanges", function(from) {
   rownames(meta) <- NULL
   if (!is.null(rd$FILTER))
     filter <- parseFilterStrings(rd$FILTER)
-  else filter <- matrix(nrow = nrow(from), ncol = 0L)
+  else filter <- FilterMatrix(matrix(nrow = nrow(from), ncol = 0L),
+                              FilterRules())
   if (nsamp > 1L) {
     meta <- meta[rep(seq_len(nrow(meta)), nsamp),,drop=FALSE]
     filter <- filter[rep(seq_len(nrow(filter)), nsamp),,drop=FALSE]
@@ -237,9 +245,12 @@ setAs("VCF", "VRanges", function(from) {
     ranges <- rep(ranges, nsamp)
     alt <- rep(alt, nsamp)
     ref <- rep(ref, nsamp)
+  } else if (nsamp == 0L && !is.null(meta$DP)) {
+    totalDepth <- meta$DP
+    meta$DP <- NULL
   }
-  if (!is.null(geno(from)$FT))
-    filter <- cbind(filter, parseFilterStrings(as.vector(geno(from)$FT)))
+  if (!is.null(geno(from)[["FT"]]))
+    filter <- cbind(filter, parseFilterStrings(as.vector(geno(from)[["FT"]])))
   otherGeno <- geno(from)[setdiff(names(geno(from)), c("AD", "DP", "FT"))]
   if (length(otherGeno) > 0L)
     meta <- DataFrame(meta, lapply(otherGeno, genoToMCol))
@@ -296,7 +307,7 @@ makeINFOheader <- function(x) {
     else if (is.logical(xi))
       "Flag"
     else if (is.character(xi) || is.factor(xi)) {
-      if (all(nchar(as.character(xi)) == 1L))
+      if (all(nchar(as.character(xi)) == 1L, na.rm=TRUE))
         "Character"
       else "String"
     }
