@@ -289,7 +289,7 @@ setMethod("locateVariants", c("GRanges", "GRangesList", "PromoterVariants"),
 
         if (asHits)
             return(.consolidateHits(fo, length(query), length(subject),
-                elementLengths(subject)))
+                elementNROWS(subject)))
 
         if (length(fo) > 0) {
             queryid <- queryHits(fo)
@@ -415,10 +415,12 @@ setMethod("locateVariants", c("GRanges", "TxDb", "AllVariants"),
 
     if (asHits)
         return(.consolidateHits(fo, length(query), length(subject),
-            elementLengths(subject))) 
+            elementNROWS(subject))) 
     if (length(fo) > 0) {
-        df <- unique(data.frame(queryid=queryHits(fo),
-                     subjectid=togroup(subject)[subjectHits(fo)]))
+        df <- unique(data.frame(
+            queryid=queryHits(fo),
+            subjectid=togroup(PartitioningByWidth(subject))[subjectHits(fo)]
+        ))
         GRanges(seqnames=seqnames(query)[df$queryid],
                 ranges=IRanges(ranges(query)[df$queryid]),
                 strand=unlist(strand(subject), use.names=FALSE)[df$subjectid],
@@ -447,7 +449,7 @@ setMethod("locateVariants", c("GRanges", "TxDb", "AllVariants"),
     txid <- rep(seq_len(slen), elen)
     dat <- cbind(queryHits(hits), as.integer(txid[subjectHits(hits)]))
     unq <- dat[!duplicated(dat),]
-    return(Hits(unq[,1], unq[,2], qlen, slen))
+    return(Hits(unq[,1], unq[,2], qlen, slen, sort.by.query=TRUE))
 }
 
 .intergenic <- function(query, subject, region, ignore.strand, ...)
@@ -471,7 +473,7 @@ setMethod("locateVariants", c("GRanges", "TxDb", "AllVariants"),
         res
     } else {
         q_range <- query[intergenic]
-        s_genes <- rep(names(subject), elementLengths(s_range))
+        s_genes <- rep(names(subject), elementNROWS(s_range))
         s_unlist <- unlist(s_range, use.names=FALSE)
 
         ## ID all genes that fall in upstream / downstream range.
@@ -555,7 +557,7 @@ setMethod("locateVariants", c("GRanges", "TxDb", "AllVariants"),
         }
 
         ss <- runValue(strand(subject)[txHits])
-        if (any(elementLengths(ss) > 1L)) {
+        if (any(elementNROWS(ss) > 1L)) {
             warning("'subject' has multiple strands per list element; ",
                     "setting strand to '*'")
             sstrand <- Rle("*", length(txHits))
